@@ -1,7 +1,20 @@
 #-*- coding: utf-8 -*-
 
-from django import forms
-from django.contrib import admin
+# Blognajd,
+# Copyright (C) 2013, Daniel Rus Morales
+
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from inline_media.admin import AdminTextFieldWithInlinesMixin
 from inline_media.widgets import TextareaWithInlines
